from setuptools import setup

setup(
    name='pypetrophysics',
    url='https://github.com/andymcdgeo/PyPetrophysics',
    author='Andy McDonald',
    email='andymcdonaldpetro@gmail.com',
    packages=['pypetrophysics'],
    version='0.1.2',
    description='A library of petrophysical calculations',
    long_description=open('README.md').read()

)